==> certmanager-model-v1alpha2-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/AzureManagedIdentityFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AzureManagedIdentityFluentImpl<A extends AzureManagedIdentityFluent<A>> extends BaseFluent<A> implements AzureManagedIdentityFluent<A>{
  public AzureManagedIdentityFluentImpl() {
  }
  public AzureManagedIdentityFluentImpl(AzureManagedIdentity instance) {
    this.withClientID(instance.getClientID()); 
    this.withResourceID(instance.getResourceID()); 
  }
  private String clientID;
  private String resourceID;
  public String getClientID() {
    return this.clientID;
  }
  public A withClientID(String clientID) {
    this.clientID=clientID; return (A) this;
  }
  public Boolean hasClientID() {
    return this.clientID != null;
  }
  public String getResourceID() {
    return this.resourceID;
  }
  public A withResourceID(String resourceID) {
    this.resourceID=resourceID; return (A) this;
  }
  public Boolean hasResourceID() {
    return this.resourceID != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AzureManagedIdentityFluentImpl that = (AzureManagedIdentityFluentImpl) o;
    if (clientID != null ? !clientID.equals(that.clientID) :that.clientID != null) return false;
    if (resourceID != null ? !resourceID.equals(that.resourceID) :that.resourceID != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clientID,  resourceID,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clientID != null) { sb.append("clientID:"); sb.append(clientID + ","); }
    if (resourceID != null) { sb.append("resourceID:"); sb.append(resourceID); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha2-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/AzureManagedIdentityFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AzureManagedIdentityFluentImpl<A extends AzureManagedIdentityFluent<A>> extends BaseFluent<A> implements AzureManagedIdentityFluent<A>{
  public AzureManagedIdentityFluentImpl() {
  }
  public AzureManagedIdentityFluentImpl(AzureManagedIdentity instance) {
    if (instance != null) {
      this.withClientID(instance.getClientID());
      this.withResourceID(instance.getResourceID());
    }
  }
  private String clientID;
  private String resourceID;
  public String getClientID() {
    return this.clientID;
  }
  public A withClientID(String clientID) {
    this.clientID=clientID; return (A) this;
  }
  public Boolean hasClientID() {
    return this.clientID != null;
  }
  public String getResourceID() {
    return this.resourceID;
  }
  public A withResourceID(String resourceID) {
    this.resourceID=resourceID; return (A) this;
  }
  public Boolean hasResourceID() {
    return this.resourceID != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AzureManagedIdentityFluentImpl that = (AzureManagedIdentityFluentImpl) o;
    if (!java.util.Objects.equals(clientID, that.clientID)) return false;

    if (!java.util.Objects.equals(resourceID, that.resourceID)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clientID,  resourceID,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clientID != null) { sb.append("clientID:"); sb.append(clientID + ","); }
    if (resourceID != null) { sb.append("resourceID:"); sb.append(resourceID); }
    sb.append("}");
    return sb.toString();
  }
  
}
